Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Audit Manager.

Actions, resources, and condition keys for AWS Audit Manager - Service Authorization Reference

# Actions, resources, and condition keys for AWS Audit Manager

AWS Audit Manager (service prefix: `auditmanager` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Audit Manager
- Resource types defined by AWS Audit Manager
- Condition keys for AWS Audit Manager

## Actions defined by AWS Audit Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateAssessmentReportEvidenceFolder | Grants permission to associate an evidence folder with an assessment report in AWS Audit Manager | Write | assessment* |  |
BatchAssociateAssessmentReportEvidence | Grants permission to associate a list of evidence to an assessment report in AWS Audit Manager | Write | assessment* |  |
BatchCreateDelegationByAssessment | Grants permission to create delegations for an assessment in AWS Audit Manager | Write | assessment* |  |
BatchDeleteDelegationByAssessment | Grants permission to delete delegations for an assessment in AWS Audit Manager | Write | assessment* |  |
BatchDisassociateAssessmentReportEvidence | Grants permission to disassociate a list of evidence from an assessment report in AWS Audit Manager | Write | assessment* |  |
BatchImportEvidenceToAssessmentControl | Grants permission to import a list of evidence to an assessment control in AWS Audit Manager | Write | assessmentControlSet* |  |
CreateAssessment | Grants permission to create an assessment to be used with AWS Audit Manager | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateAssessmentFramework | Grants permission to create a framework for use in AWS Audit Manager | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateAssessmentReport | Grants permission to create an assessment report in AWS Audit Manager | Write | assessment* |  |
CreateControl | Grants permission to create a control to be used in AWS Audit Manager | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAssessment | Grants permission to delete an assessment in AWS Audit Manager | Write | assessment* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAssessmentFramework | Grants permission to delete an assessment framework in AWS Audit Manager | Write | assessmentFramework* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAssessmentFrameworkShare | Grants permission to delete a share request for a custom framework in AWS Audit Manager | Write |  |  |
DeleteAssessmentReport | Grants permission to delete an assessment report in AWS Audit Manager | Write | assessment* |  |
DeleteControl | Grants permission to delete a control in AWS Audit Manager | Write | control* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeregisterAccount | Grants permission to deregister an account in AWS Audit Manager | Write |  |  |
DeregisterOrganizationAdminAccount | Grants permission to deregister the delegated administrator account for AWS Audit Manager | Write |  |  |
DisassociateAssessmentReportEvidenceFolder | Grants permission to disassociate an evidence folder from an assessment report in AWS Audit Manager | Write | assessment* |  |
GetAccountStatus | Grants permission to get the status of an account in AWS Audit Manager | Read |  |  |
GetAssessment | Grants permission to get an assessment created in AWS Audit Manager | Read | assessment* |  |
GetAssessmentFramework | Grants permission to get an assessment framework in AWS Audit Manager | Read | assessmentFramework* |  |
GetAssessmentReportUrl | Grants permission to get the URL for an assessment report in AWS Audit Manager | Read | assessment* |  |
GetChangeLogs | Grants permission to get changelogs for an assessment in AWS Audit Manager | Read | assessment* |  |
GetControl | Grants permission to get a control in AWS Audit Manager | Read | control* |  |
GetDelegations | Grants permission to get all delegations in AWS Audit Manager | List |  |  |
GetEvidence | Grants permission to get evidence from AWS Audit Manager | Read | assessmentControlSet* |  |
GetEvidenceByEvidenceFolder | Grants permission to get all the evidence from an evidence folder in AWS Audit Manager | Read | assessmentControlSet* |  |
GetEvidenceFolder | Grants permission to get the evidence folder from AWS Audit Manager | Read | assessmentControlSet* |  |
GetEvidenceFoldersByAssessment | Grants permission to get the evidence folders from an assessment in AWS Audit Manager | Read | assessment* |  |
GetEvidenceFoldersByAssessmentControl | Grants permission to get the evidence folders from an assessment control in AWS Audit Manager | Read | assessmentControlSet* |  |
GetInsights | Grants permission to get analytics data for all active assessments | Read |  |  |
GetInsightsByAssessment | Grants permission to get analytics data for a specific active assessment | Read |  |  |
GetOrganizationAdminAccount | Grants permission to get the delegated administrator account in AWS Audit Manager | Read |  |  |
GetServicesInScope | Grants permission to get the services in scope for an assessment in AWS Audit Manager | Read |  |  |
GetSettings | Grants permission to get all settings configured in AWS Audit Manager | Read |  |  |
ListAssessmentControlInsightsByControlDomain | Grants permission to list analytics data for controls in a specific control domain and active assessment | List |  |  |
ListAssessmentFrameworkShareRequests | Grants permission to list all sent or received share requests for custom frameworks in AWS Audit Manager | List |  |  |
ListAssessmentFrameworks | Grants permission to list all assessment frameworks in AWS Audit Manager | List |  |  |
ListAssessmentReports | Grants permission to list all assessment reports in AWS Audit Manager | List |  |  |
ListAssessments | Grants permission to list all assessments in AWS Audit Manager | List |  |  |
ListControlDomainInsights | Grants permission to list analytics data for control domains across all active assessments | List |  |  |
ListControlDomainInsightsByAssessment | Grants permission to list analytics data for control domains in a specific active assessment | List |  |  |
ListControlInsightsByControlDomain | Grants permission to list analytics data for controls in a specific control domain across all active assessments | List |  |  |
ListControls | Grants permission to list all controls in AWS Audit Manager | List |  |  |
ListKeywordsForDataSource | Grants permission to list all the data source keywords in AWS Audit Manager | List |  |  |
ListNotifications | Grants permission to list all notifications in AWS Audit Manager | List |  |  |
ListTagsForResource | Grants permission to list tags for an AWS Audit Manager resource | Read | assessment |  |
control |  |
RegisterAccount | Grants permission to register an account in AWS Audit Manager | Write |  |  |
RegisterOrganizationAdminAccount | Grants permission to register an account within the organization as the delegated administrator for AWS Audit Manager | Write |  |  |
StartAssessmentFrameworkShare | Grants permission to create a share request for a custom framework in AWS Audit Manager | Write | assessmentFramework* |  |
TagResource | Grants permission to tag an AWS Audit Manager resource | Tagging | assessment |  |
control |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag an AWS Audit Manager resource | Tagging | assessment |  |
control |  |
| aws:TagKeys |
UpdateAssessment | Grants permission to update an assessment in AWS Audit Manager | Write | assessment* |  |
UpdateAssessmentControl | Grants permission to update an assessment control in AWS Audit Manager | Write | assessmentControlSet* |  |
UpdateAssessmentControlSetStatus | Grants permission to update the status of an assessment control set in AWS Audit Manager | Write | assessmentControlSet* |  |
UpdateAssessmentFramework | Grants permission to update an assessment framework in AWS Audit Manager | Write | assessmentFramework* |  |
UpdateAssessmentFrameworkShare | Grants permission to update a share request for a custom framework in AWS Audit Manager | Write |  |  |
UpdateAssessmentStatus | Grants permission to update the status of an assessment in AWS Audit Manager | Write | assessment* |  |
UpdateControl | Grants permission to update a control in AWS Audit Manager | Write | control* |  |
UpdateSettings | Grants permission to update settings in AWS Audit Manager | Write |  |  |
ValidateAssessmentReportIntegrity | Grants permission to validate the integrity of an assessment report in AWS Audit Manager | Read |  |  |

## Resource types defined by AWS Audit Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
assessment | `arn:$ { Partition}:auditmanager:$ { Region}:$ { Account}:assessment/$ { AssessmentId}` |
assessmentFramework | `arn:$ { Partition}:auditmanager:$ { Region}:$ { Account}:assessmentFramework/$ { AssessmentFrameworkId}` |
assessmentControlSet | `arn:$ { Partition}:auditmanager:$ { Region}:$ { Account}:assessment/$ { AssessmentId}/ControlSet/$ { ControlSetId}` |
control | `arn:$ { Partition}:auditmanager:$ { Region}:$ { Account}:control/$ { ControlId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Audit Manager

AWS Audit Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.